@@ -13,7 +13,7 @@ pub fn structured_error_handler(ctx: *mut c_void, error: bindings::xmlErrorPtr)
   assert!(!ctx.is_null());
   let errlog = unsafe { &mut *{ ctx as *mut Vec<StructuredError> } };
 
-  let error = StructuredError::from_raw(error);
+  let error = unsafe { StructuredError::from_raw(error) };
 
   errlog.push(error);
 }
