@@ -83,7 +83,7 @@ impl SchemaValidationContext {
   pub fn drain_errors(&mut self) -> Vec<StructuredError> {
     assert!(!self.errlog.is_null());
     let errors = unsafe { &mut *self.errlog };
-    errors.drain(0..).collect()
+    std::mem::take(errors)
   }
 
   /// Return a raw pointer to the underlying xmlSchemaValidCtxt structure
@@ -95,7 +95,7 @@ impl SchemaValidationContext {
 /// Private Interface
 impl SchemaValidationContext {
   fn from_raw(ctx: *mut bindings::_xmlSchemaValidCtxt, schema: Schema) -> Self {
-    let errors: Box<Vec<StructuredError>> = Box::new(Vec::new());
+    let errors: Box<Vec<StructuredError>> = Box::default();
 
     unsafe {
       let reference: *mut Vec<StructuredError> = std::mem::transmute(errors);
